import { AxiosPromise } from 'axios';
import { OmiseError } from './models/Error';
export interface Config {
    omiseVersion?: '2019-05-29';
    publicKey: string;
    secretKey: string;
    apiBaseUrl?: string;
    vaultBaseUrl?: string;
}
export declare abstract class Client {
    protected config: Config;
    protected abstract baseURL: string;
    protected get apiBaseUrl(): string;
    protected get vaultBaseUrl(): string;
    constructor(config: Config);
    protected abstract getKey(): string;
    protected getRequest<T>(request: AxiosPromise<any>): Promise<T | OmiseError>;
    protected post<T>(endpoint: string, data?: any, apiKey?: string, omiseVersion?: string): Promise<T | OmiseError>;
    protected get<T>(endpoint: string, params?: any, apiKey?: string, omiseVersion?: string): Promise<T | OmiseError>;
    protected patch<T>(endpoint: string, data?: any, apiKey?: string, omiseVersion?: string): Promise<T | OmiseError>;
    protected put<T>(endpoint: string, data?: any, apiKey?: string, omiseVersion?: string): Promise<T | OmiseError>;
    protected delete<T>(endpoint: string, data?: any, apiKey?: string, omiseVersion?: string): Promise<T | OmiseError>;
    protected fileUpload<T>(endpoint: string, data?: any, apiKey?: string, omiseVersion?: string): Promise<T | OmiseError>;
    private buildConfigure;
}
